@@ -1,7 +1,6 @@
 """Data imports, sampling and generation."""
 
-from typing import (Callable, Dict, Iterator, List, Literal, Optional, Tuple,
-                    Union)
+from typing import Callable, Dict, Iterator, List, Literal, Optional, Tuple, Union
 
 import instancelib as il
 import pandas as pd
@@ -67,22 +66,26 @@ def import_data(dataset,
 
     Examples:
         Import from an online .csv file with data in the 'text' column and labels in 'category':
+
         >>> from genbase import import_data
         >>> ds = import_data('https://storage.googleapis.com/dataset-uploader/bbc/bbc-text.csv',
                              data_cols='text', label_cols='category')
 
         Convert a pandas DataFrame to instancelib Environment:
+
         >>> from genbase import import_data
         >>> import pandas as pd
         >>> df = pd.read_csv('https://storage.googleapis.com/dataset-uploader/bbc/bbc-text.csv')
         >>> ds = import_data(df, data_cols='text', label_cols='category')
 
         Download a .zip file and convert each file in the zip to an instancelib Environment:
+
         >>> from genbase import import_data
         >>> ds = import_data('https://archive.ics.uci.edu/ml/machine-learning-databases/00462/drugsCom_raw.zip',
                              data_cols='review', label_cols='rating')
 
         Convert a huggingface dataset (sst2) to an instancelib Environment:
+
         >>> from genbase import import_data
         >>> from datasets import load_dataset
         >>> ds = import_data(load_dataset('glue', 'sst2'), data_cols='sentence', label_cols='label')
@@ -141,7 +144,7 @@ def import_data(dataset,
                                       data_cols=data_cols,
                                       label_cols=label_cols,
                                       label_map=label_map,
-                                      method=method,
+                                      method='infer',
                                       **read_kwargs)
 
     # Read one file with Pandas
@@ -151,9 +154,9 @@ def import_data(dataset,
             if file_type in ['.csv', '.tsv', '.txt']:
                 if 'sep' not in read_kwargs:
                     if file_type == '.csv':
-                        read_kwargs['sep']= ','
+                        read_kwargs['sep'] = ','
                     elif file_type == '.tsv':
-                        read_kwargs['sep']= '\t'
+                        read_kwargs['sep'] = '\t'
                 dataset = pd.read_csv(dataset, **read_kwargs)
             elif file_type == '.json':
                 dataset = pd.read_json(dataset, **read_kwargs)
